@@ -102,3 +102,10 @@ def get_shortcut_class(url):
     return ''
 
 
+@register.simple_tag
+def admin_static_url():
+    """
+    If set, returns the string contained in the setting ADMIN_MEDIA_PREFIX, otherwise returns STATIC_URL + 'admin/'.
+    """
+    return getattr(settings, 'ADMIN_MEDIA_PREFIX', None) or ''.join([settings.STATIC_URL, 'admin/'])
+
